@@ -1,3 +1,4 @@
+/* vim:set noexpandtab sts=8 sw=8: */
 /*
  * Copyright (C) 2007 The GNOME Foundation
  * Written by Thomas Wood <thos@gnome.org>
@@ -22,15 +23,10 @@
 #include "appearance.h"
 
 #include <string.h>
-#include <libwindow-settings/gnome-wm-manager.h>
-#include <libgnomevfs/gnome-vfs-async-ops.h>
-#include <libgnomevfs/gnome-vfs-ops.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#include <glib.h>
+#include <glib/gi18n.h>
+#include <gio/gio.h>
 
-#include "gnome-theme-info.h"
-#include "capplet-util.h"
-#include "activate-settings-daemon.h"
-#include "gconf-property-editor.h"
 #include "file-transfer-dialog.h"
 #include "theme-installer.h"
 #include "theme-util.h"
@@ -165,8 +161,11 @@ transfer_cancel_cb (GtkWidget *dlg, gchar *path)
 static void
 missing_utility_message_dialog (const gchar *utility)
 {
-	GtkWidget *dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-				_("Cannot install theme.\nThe %s utility is not installed."), utility);
+	GtkWidget *dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
+			GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+			_("Cannot install theme"));
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+			_("The %s utility is not installed."), utility);
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 }
@@ -214,7 +213,9 @@ transfer_done_tgz_tbz (const gchar *util, const gchar *tmp_dir, const gchar *arc
 		GtkWidget *dialog;
 
 		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-				_("Cannot install theme.\nThere was a problem while extracting the theme."));
+				_("Cannot install theme"));
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+				_("There was a problem while extracting the theme."));
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
 	}
@@ -233,6 +234,26 @@ transfer_done_archive (gint filetype, const gchar *tmp_dir, const gchar *archive
 		return FALSE;
 }
 
+static void
+invalid_theme_dialog (const gchar *filename, gboolean maybe_theme_engine)
+{
+	GtkWidget *dialog;
+	const gchar *primary = _("There was an error installing the selected file");
+	const gchar *secondary = _("\"%s\" does not appear to be a valid theme.");
+	const gchar *engine = _("\"%s\" does not appear to be a valid theme. It may be a theme engine which you need to compile.");
+
+	dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
+			GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, primary);
+	if (maybe_theme_engine)
+		gtk_message_dialog_format_secondary_text (
+				GTK_MESSAGE_DIALOG (dialog), engine, filename);
+	else
+		gtk_message_dialog_format_secondary_text (
+				GTK_MESSAGE_DIALOG (dialog), secondary, filename);
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
+}
+
 static gboolean
 gnome_theme_install_real (gint filetype, const gchar *tmp_dir, const gchar *theme_name, gboolean ask_user)
 {
@@ -268,22 +289,10 @@ gnome_theme_install_real (gint filetype, const gchar *tmp_dir, const gchar *them
 					   theme_name, NULL);
 		break;
 	case THEME_ENGINE:
-		dialog = gtk_message_dialog_new (NULL,
-			       GTK_DIALOG_MODAL,
-			       GTK_MESSAGE_ERROR,
-			       GTK_BUTTONS_OK,
-			       _("The selected file is not a valid theme. It might be a theme engine that you need to compile."));
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
+		invalid_theme_dialog (theme_name, TRUE);
 		return FALSE;
 	default:
-		dialog = gtk_message_dialog_new (NULL,
-			       GTK_DIALOG_MODAL,
-			       GTK_MESSAGE_ERROR,
-			       GTK_BUTTONS_OK,
-			       _("The selected file does not appear to be a valid theme."));
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
+		invalid_theme_dialog (theme_name, FALSE);
 		return FALSE;
 	}
 
@@ -447,13 +456,10 @@ transfer_done_cb (GtkWidget *dlg, gchar *path)
 	else if (g_file_test (path, G_FILE_TEST_IS_DIR))
 		filetype = DIRECTORY;
 	else {
-		dialog = gtk_message_dialog_new (NULL,
-						GTK_DIALOG_MODAL,
-						GTK_MESSAGE_ERROR,
-						GTK_BUTTONS_OK,
-						_("The selected file does not appear to be a valid theme."));
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
+		gchar *filename;
+		filename = g_path_get_basename (path);
+		invalid_theme_dialog (filename, FALSE);
+		g_free (filename);
 		g_free (path);
 		return;
 	}
@@ -555,7 +561,6 @@ gnome_theme_install_from_uri (const gchar *filename, GtkWindow *parent)
 	GtkWidget *dialog;
 	gchar *path, *base;
 	GList *src, *target;
-	GnomeVFSURI *uri;
 	gchar *temppath;
 	const gchar *template;
 	int cmp;
@@ -613,55 +618,50 @@ gnome_theme_install_from_uri (const gchar *filename, GtkWindow *parent)
 		return;
 	}
 
-	uri = gnome_vfs_uri_new (filename);
-	base = gnome_vfs_uri_extract_short_name (uri);
-	src = g_list_append (NULL, uri);
+	base = g_path_get_basename (filename);
 
 	if (g_str_has_suffix (base, ".tar.gz") || g_str_has_suffix (base, ".tgz") || g_str_has_suffix (base, ".gtp"))
 		template = "gnome-theme-%d.gtp";
 	else if (g_str_has_suffix (base, ".tar.bz2"))
 		template = "gnome-theme-%d.tar.bz2";
 	else {
-		dialog = gtk_message_dialog_new (NULL,
-					GTK_DIALOG_MODAL,
-					GTK_MESSAGE_ERROR,
-					GTK_BUTTONS_OK,
-					_("The selected file does not appear to be a valid theme."));
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
+		invalid_theme_dialog (base, FALSE);
 		g_free (base);
 		gnome_vfs_uri_list_unref (src);
 		return;
 	}
 	g_free (base);
 
+	src = g_list_append (NULL, g_strdup (filename));
+
 	path = NULL;
 	do {
 	  	gchar *file_tmp;
 
 		g_free (path);
-    		file_tmp = g_strdup_printf (template, rand ());
+    		file_tmp = g_strdup_printf (template, g_random_int ());
 	    	path = g_build_filename (g_get_home_dir (), ".themes", file_tmp, NULL);
 	  	g_free (file_tmp);
 	} while (g_file_test (path, G_FILE_TEST_EXISTS));
 
 
-	target = g_list_append (NULL, gnome_vfs_uri_new (path));
+	target = g_list_append (NULL, path);
 
 	dialog = file_transfer_dialog_new_with_parent (parent);
-	file_transfer_dialog_wrap_async_xfer (FILE_TRANSFER_DIALOG (dialog),
-					      src, target,
-					      GNOME_VFS_XFER_RECURSIVE,
-					      GNOME_VFS_XFER_ERROR_MODE_QUERY,
-					      GNOME_VFS_XFER_OVERWRITE_MODE_QUERY,
-					      GNOME_VFS_PRIORITY_DEFAULT);
-	gnome_vfs_uri_list_unref (src);
-	gnome_vfs_uri_list_unref (target);
-	g_signal_connect (G_OBJECT (dialog), "cancel",
-			  G_CALLBACK (transfer_cancel_cb), path);
-	g_signal_connect (G_OBJECT (dialog), "done",
-			  G_CALLBACK (transfer_done_cb), path);
+	g_signal_connect (dialog, "cancel",
+			  (GCallback) transfer_cancel_cb, path);
+	g_signal_connect (dialog, "done",
+			  (GCallback) transfer_done_cb, path);
+
+	file_transfer_dialog_copy_async (FILE_TRANSFER_DIALOG (dialog),
+					 src, target,
+					 G_PRIORITY_DEFAULT);
 	gtk_widget_show (dialog);
+
+	g_list_foreach (src, (GFunc) g_free, NULL);
+	/* don't free the target item since we're using that for the signals */
+	g_list_free (src);
+	g_list_free (target);
 }
 
 void
@@ -702,20 +702,23 @@ gnome_theme_installer_run (GtkWindow *parent, const gchar *filename)
 	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
 	{
 		filename_selected = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+
+		folder = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (dialog));
+		g_strlcpy (old_folder, folder, 255);
+		g_free (folder);
+
+		gtk_widget_destroy (dialog);
+
 		gnome_theme_install_from_uri (filename_selected, parent);
 		g_free (filename_selected);
 	}
-
-	folder = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (dialog));
-	g_strlcpy (old_folder, folder, 255);
-	g_free (folder);
+	else
+		gtk_widget_destroy (dialog);
 
 	/*
 	 * we're relying on the gnome theme info module to pick up changes
 	 * to the themes so we don't need to update the model here
 	 */
 
-	gtk_widget_destroy (dialog);
-
 	running_theme_install = FALSE;
 }
