@@ -7,6 +7,7 @@
 #include <metacity-private/preview-widget.h>
 #include <signal.h>
 #include <errno.h>
+#include <math.h>
 
 /* We have to #undef this as metacity #defines these. */
 #undef _
@@ -40,11 +41,11 @@ static ThemeThumbnailAsyncData async_data;
 
 /* Protocol */
 
-/* Our protocol is pretty simple.  The parent process will write four strings
- * (separated by a '\000') They are the widget theme, the wm theme, the icon
- * theme, and the font string.  Then, it will wait for the child to write back
- * the data.  The parent expects ICON_SIZE_WIDTH * ICON_SIZE_HEIGHT * 4 bytes of
- * information.  After that, the child is ready for the next theme to render.
+/* Our protocol is pretty simple.  The parent process will write several strings
+ * (separated by a '\000'). They are the widget theme, the wm theme, the icon
+ * theme, etc.  Then, it will wait for the child to write back the data.  The
+ * parent expects ICON_SIZE_WIDTH * ICON_SIZE_HEIGHT * 4 bytes of information.
+ * After that, the child is ready for the next theme to render.
  */
 
 enum
@@ -121,10 +122,45 @@ static void
 hbox_foreach (GtkWidget *widget,
               gpointer   data)
 {
-  gtk_widget_realize (widget);
-  gtk_widget_map (widget);
-  gtk_widget_ensure_style (widget);
-  fake_expose_widget (widget, (GdkPixmap *) data, NULL);
+  if (GTK_WIDGET_VISIBLE (widget)) {
+    gtk_widget_realize (widget);
+    gtk_widget_map (widget);
+    gtk_widget_ensure_style (widget);
+    fake_expose_widget (widget, (GdkPixmap *) data, NULL);
+  }
+}
+
+static void
+pixbuf_apply_mask_region (GdkPixbuf *pixbuf, GdkRegion *region)
+{
+  gint nchannels, rowstride, w, h;
+  guchar *pixels, *p;
+
+  g_return_if_fail (pixbuf);
+  g_return_if_fail (region);
+
+  nchannels = gdk_pixbuf_get_n_channels (pixbuf);
+  rowstride = gdk_pixbuf_get_rowstride (pixbuf);
+  pixels = gdk_pixbuf_get_pixels (pixbuf);
+
+
+  /* we need an alpha channel ... */
+  if (!gdk_pixbuf_get_has_alpha (pixbuf) || nchannels != 4)
+    return;
+
+  for (w = 0; w < gdk_pixbuf_get_width (pixbuf); ++w)
+    for (h = 0; h < gdk_pixbuf_get_height (pixbuf); ++h)
+    {
+      if (!gdk_region_point_in (region, w, h))
+      {
+        p = pixels + h * rowstride + w * nchannels;
+        if (G_BYTE_ORDER == G_BIG_ENDIAN)
+          p[0] = 0x0;
+        else
+          p[3] = 0x0;
+      }
+    }
+
 }
 
 static GdkPixbuf *
@@ -224,6 +260,7 @@ create_meta_theme_pixbuf (ThemeThumbnailData *theme_thumbnail_data)
   MetaTheme *theme;
   GdkPixbuf *pixbuf, *icon;
   int icon_width, icon_height;
+  GdkRegion *region;
 
   g_object_set (gtk_settings_get_default (),
     "gtk-theme-name", (char *) theme_thumbnail_data->control_theme_name->data,
@@ -327,8 +364,14 @@ create_meta_theme_pixbuf (ThemeThumbnailData *theme_thumbnail_data)
                         vbox->allocation.x + vbox->allocation.width - icon_width - 5,
                         vbox->allocation.y + vbox->allocation.height - icon_height - 5,
                         1.0, 1.0, GDK_INTERP_BILINEAR, 255);
+  region = meta_preview_get_clip_region (META_PREVIEW (preview),
+      META_THUMBNAIL_SIZE, META_THUMBNAIL_SIZE);
+  pixbuf_apply_mask_region (pixbuf, region);
+  gdk_region_destroy (region);
+
   g_object_unref (icon);
   gtk_widget_destroy (window);
+  meta_theme_free (theme);
 
   return pixbuf;
 }
@@ -427,6 +470,7 @@ create_metacity_theme_pixbuf (ThemeThumbnailData *theme_thumbnail_data)
   GdkVisual *visual;
   GdkPixmap *pixmap;
   GdkPixbuf *pixbuf, *retval;
+  GdkRegion *region;
 
   theme = meta_theme_load ((char *) theme_thumbnail_data->wm_theme_name->data, NULL);
 
@@ -483,6 +527,12 @@ create_metacity_theme_pixbuf (ThemeThumbnailData *theme_thumbnail_data)
   pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, (int) METACITY_THUMBNAIL_WIDTH * 1.2, (int) METACITY_THUMBNAIL_HEIGHT * 1.2);
   gdk_pixbuf_get_from_drawable (pixbuf, pixmap, NULL, 0, 0, 0, 0, (int) METACITY_THUMBNAIL_WIDTH * 1.2, (int) METACITY_THUMBNAIL_HEIGHT * 1.2);
 
+  region = meta_preview_get_clip_region (META_PREVIEW (preview),
+      METACITY_THUMBNAIL_WIDTH * 1.2, METACITY_THUMBNAIL_HEIGHT * 1.2);
+  pixbuf_apply_mask_region (pixbuf, region);
+  gdk_region_destroy (region);
+
+
   retval = gdk_pixbuf_scale_simple (pixbuf,
                                     METACITY_THUMBNAIL_WIDTH,
                                     METACITY_THUMBNAIL_HEIGHT,
@@ -747,6 +797,11 @@ message_from_child (GIOChannel   *source,
   if (async_data.set == FALSE)
     return TRUE;
 
+  if (condition == G_IO_HUP)
+  {
+    return FALSE;
+  }
+
   status = g_io_channel_read_chars (source,
                                     buffer,
                                     1024,
@@ -807,7 +862,7 @@ message_from_child (GIOChannel   *source,
 
     case G_IO_STATUS_EOF:
     case G_IO_STATUS_ERROR:
-      return TRUE;
+      return FALSE;
 
     default:
       g_assert_not_reached ();
@@ -935,12 +990,17 @@ generate_meta_theme_thumbnail (GnomeThemeMetaInfo *theme_info)
 GdkPixbuf *
 generate_gtk_theme_thumbnail (GnomeThemeInfo *theme_info)
 {
+  gchar *scheme;
+
+  scheme = gtkrc_get_color_scheme_for_theme (theme_info->name);
+
   return generate_theme_thumbnail (THUMBNAIL_TYPE_GTK,
                                    theme_info->name,
-                                   NULL,
+                                   scheme,
                                    NULL,
                                    NULL,
                                    NULL);
+  g_free (scheme);
 }
 
 GdkPixbuf *
@@ -978,8 +1038,6 @@ generate_theme_thumbnail_async (gpointer            theme_info,
                                 gpointer            user_data,
                                 GDestroyNotify      destroy)
 {
-  gchar *scheme;
-
   if (async_data.set)
   {
     ThemeQueueItem *item;
@@ -1021,18 +1079,12 @@ generate_theme_thumbnail_async (gpointer            theme_info,
   async_data.user_data = user_data;
   async_data.destroy = destroy;
 
-  if (!strcmp (thumbnail_type, THUMBNAIL_TYPE_GTK)) {
-    scheme = gtkrc_get_color_scheme_for_theme (theme_name);
-    gtk_color_scheme = scheme;
-  } else scheme = NULL;
-
   send_thumbnail_request (thumbnail_type,
                           gtk_theme_name,
                           gtk_color_scheme,
                           metacity_theme_name,
                           icon_theme_name,
                           application_font);
-  g_free (scheme);
 }
 
 void
@@ -1058,15 +1110,20 @@ generate_gtk_theme_thumbnail_async (GnomeThemeInfo *theme_info,
                                     gpointer            user_data,
                                     GDestroyNotify      destroy)
 {
+  gchar *scheme;
+
+  scheme = gtkrc_get_color_scheme_for_theme (theme_info->name);
+
   generate_theme_thumbnail_async (theme_info,
-                                         theme_info->name,
-                                         THUMBNAIL_TYPE_GTK,
-                                         theme_info->name,
-                                         NULL,
-                                         NULL,
-                                         NULL,
-                                         NULL,
-                                         func, user_data, destroy);
+                                  theme_info->name,
+                                  THUMBNAIL_TYPE_GTK,
+                                  theme_info->name,
+                                  scheme,
+                                  NULL,
+                                  NULL,
+                                  NULL,
+                                  func, user_data, destroy);
+  g_free (scheme);
 }
 
 void
